@@ -12,9 +12,9 @@ use String::ShellQuote;
 use Exporter 'import';
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-05-28'; # DATE
+our $DATE = '2022-06-13'; # DATE
 our $DIST = 'Perinci-CmdLine-POD'; # DIST
-our $VERSION = '0.028'; # VERSION
+our $VERSION = '0.029'; # VERSION
 
 our @EXPORT_OK = qw(gen_pod_for_pericmd_script);
 
@@ -435,10 +435,13 @@ sub gen_pod_for_pericmd_script {
         }
         if (@examples) {
             $has_examples++;
+            my $num = 0;
             for my $eg (@examples) {
+                $num++;
                 my $url = $urls{ $eg->{_sc_name} };
                 my $meta = $metas{ $eg->{_sc_name} };
-                push @sectpod, "$eg->{summary}:\n\n" if $eg->{summary};
+                my $title = $eg->{summary} ? $eg->{summary} : "Example #$num";
+                push @sectpod, "=head2 $title\n\n";
                 my $cmdline = $eg->{cmdline};
                 $cmdline =~ s/\[\[prog\]\]/$cli->{subcommands} ? "$program_name $eg->{_sc_name}" : $program_name/e;
                 push @sectpod, " % $cmdline\n";
@@ -508,6 +511,13 @@ sub gen_pod_for_pericmd_script {
                 unless ($show_result) {
                     push @sectpod, "\n";
                 }
+
+                if ($eg->{description}) {
+                    require Markdown::To::POD;
+
+                    push @sectpod, Markdown::To::POD::markdown_to_pod($eg->{description}), "\n\n";
+                }
+
             } # for example
         } # if @examples
 
@@ -1028,7 +1038,7 @@ Perinci::CmdLine::POD - Generate POD for Perinci::CmdLine-based CLI script
 
 =head1 VERSION
 
-This document describes version 0.028 of Perinci::CmdLine::POD (from Perl distribution Perinci-CmdLine-POD), released on 2022-05-28.
+This document describes version 0.029 of Perinci::CmdLine::POD (from Perl distribution Perinci-CmdLine-POD), released on 2022-06-13.
 
 =head1 SYNOPSIS
 
